NetworkX 3.4.1
==============

Release date: 11 October 2024

Supports Python 3.10, 3.11, 3.12, and 3.13.

NetworkX is a Python package for the creation, manipulation, and study of the
structure, dynamics, and functions of complex networks.

For more information, please visit our `website <https://networkx.org/>`_
and our :ref:`gallery of examples <examples_gallery>`.
Please send comments and questions to the `networkx-discuss mailing list
<http://groups.google.com/group/networkx-discuss>`_.

Maintenance
-----------

- Remove old deprecation decorator (`#7669 <https://github.com/networkx/networkx/pull/7669>`_).
- MAINT: delay loading of backend_info to after imports (`#7672 <https://github.com/networkx/networkx/pull/7672>`_).

Contributors
------------

2 authors added to this release (alphabetically):

- Dan Schult (`@dschult <https://github.com/dschult>`_)
- Jarrod Millman (`@jarrodmillman <https://github.com/jarrodmillman>`_)

3 reviewers added to this release (alphabetically):

- Jarrod Millman (`@jarrodmillman <https://github.com/jarrodmillman>`_)
- Mridul Seth (`@MridulS <https://github.com/MridulS>`_)
- Ross Barnowski (`@rossbar <https://github.com/rossbar>`_)

_These lists are automatically generated, and may not be complete or may contain duplicates._
